==> quarkus-core-deployment-3.10.2-sources.jar: io/quarkus/deployment/BootstrapConfig$$accessor.java <==
package io.quarkus.deployment;
@io.quarkus.Generated("Quarkus annotation processor")
public final class BootstrapConfig$$accessor {
    private BootstrapConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_effectiveModelBuilder(Object __instance) {
        return ((BootstrapConfig)__instance).effectiveModelBuilder;
    }
    @SuppressWarnings("unchecked")
    public static void set_effectiveModelBuilder(Object __instance, boolean effectiveModelBuilder) {
        ((BootstrapConfig)__instance).effectiveModelBuilder = effectiveModelBuilder;
    }
    @SuppressWarnings("unchecked")
    public static Object get_workspaceDiscovery(Object __instance) {
        return ((BootstrapConfig)__instance).workspaceDiscovery;
    }
    @SuppressWarnings("unchecked")
    public static void set_workspaceDiscovery(Object __instance, Object workspaceDiscovery) {
        ((BootstrapConfig)__instance).workspaceDiscovery = (Boolean)workspaceDiscovery;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_warnOnFailingWorkspaceModules(Object __instance) {
        return ((BootstrapConfig)__instance).warnOnFailingWorkspaceModules;
    }
    @SuppressWarnings("unchecked")
    public static void set_warnOnFailingWorkspaceModules(Object __instance, boolean warnOnFailingWorkspaceModules) {
        ((BootstrapConfig)__instance).warnOnFailingWorkspaceModules = warnOnFailingWorkspaceModules;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_disableJarCache(Object __instance) {
        return ((BootstrapConfig)__instance).disableJarCache;
    }
    @SuppressWarnings("unchecked")
    public static void set_disableJarCache(Object __instance, boolean disableJarCache) {
        ((BootstrapConfig)__instance).disableJarCache = disableJarCache;
    }
}

==> quarkus-core-deployment-3.13.3-sources.jar: io/quarkus/deployment/BootstrapConfig$$accessor.java <==
package io.quarkus.deployment;
@io.quarkus.Generated("Quarkus annotation processor")
public final class BootstrapConfig$$accessor {
    private BootstrapConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_effectiveModelBuilder(Object __instance) {
        return ((BootstrapConfig)__instance).effectiveModelBuilder;
    }
    @SuppressWarnings("unchecked")
    public static void set_effectiveModelBuilder(Object __instance, boolean effectiveModelBuilder) {
        ((BootstrapConfig)__instance).effectiveModelBuilder = effectiveModelBuilder;
    }
    @SuppressWarnings("unchecked")
    public static Object get_workspaceDiscovery(Object __instance) {
        return ((BootstrapConfig)__instance).workspaceDiscovery;
    }
    @SuppressWarnings("unchecked")
    public static void set_workspaceDiscovery(Object __instance, Object workspaceDiscovery) {
        ((BootstrapConfig)__instance).workspaceDiscovery = (Boolean)workspaceDiscovery;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_warnOnFailingWorkspaceModules(Object __instance) {
        return ((BootstrapConfig)__instance).warnOnFailingWorkspaceModules;
    }
    @SuppressWarnings("unchecked")
    public static void set_warnOnFailingWorkspaceModules(Object __instance, boolean warnOnFailingWorkspaceModules) {
        ((BootstrapConfig)__instance).warnOnFailingWorkspaceModules = warnOnFailingWorkspaceModules;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_disableJarCache(Object __instance) {
        return ((BootstrapConfig)__instance).disableJarCache;
    }
    @SuppressWarnings("unchecked")
    public static void set_disableJarCache(Object __instance, boolean disableJarCache) {
        ((BootstrapConfig)__instance).disableJarCache = disableJarCache;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_incubatingModelResolver(Object __instance) {
        return ((BootstrapConfig)__instance).incubatingModelResolver;
    }
    @SuppressWarnings("unchecked")
    public static void set_incubatingModelResolver(Object __instance, boolean incubatingModelResolver) {
        ((BootstrapConfig)__instance).incubatingModelResolver = incubatingModelResolver;
    }
}
